@@ -478,8 +478,7 @@ def qt_message_handler(mode, ctx, message):
     }.get(mode, logging.INFO)
     logging.log(level, "Qt: %s (%s:%d)", message, ctx.file, ctx.line)
 
-qInstallMessageHandler(qt_message_handler)
-print("ASDFFAWEDSASFDAFSDAFSD")
+
 # Callable startConsole tool
 # --- startConsole: instantiate first, then wire workers/logs
 def startConsole(console_class, *args, **kwargs):
